@@ -6,6 +6,7 @@
 #' @param y Name of y variable, Defaults to NULL. The input data will split based on the predictor y, if it is provide.
 #' @param ratios A numeric vector indicating the ratio of total rows contained in each split, defaults to c(0.7, 0.3).
 #' @param name_dfs Name of returned data frames. Its length should equals to the ratios'. Defaults to train and test.
+#' @param oot out-of-time validation data set parameters.
 #' @param seed A random seed, Defaults to 618.
 #' @param ... Additional parameters.
 #'
@@ -30,7 +31,12 @@
 #'
 #' @import data.table
 #' @export
-split_df = function(dt, y=NULL, ratios=c(0.7, 0.3), name_dfs=c('train', 'test'), seed=618, ...) {
+split_df = function(dt, y=NULL, ratios=c(0.7, 0.3), name_dfs=c('train', 'test'), oot=list(order=NULL, start=NULL, ratio=NULL), seed=618, ...) {
+  UseMethod('split_df')
+}
+
+#' @export
+split_df.data.frame = function(dt, y=NULL, ratios=c(0.7, 0.3), name_dfs=c('train', 'test'), oot=list(order=NULL, start=NULL, ratio=NULL), seed=618, ...) {
   ind = NULL
 
   # set dt as data.table
@@ -56,6 +62,22 @@ split_df = function(dt, y=NULL, ratios=c(0.7, 0.3), name_dfs=c('train', 'test'),
     if (ratio_ > 0) ratios = c(ratios, ratio_)
   }
 
+  # oot, out of time
+  dt_oot = NULL
+  if (!is.null(oot$order) & (is.null(oot$start) + is.null(oot$ratio) == 1)) {
+    setorderv(dt, oot$order)
+
+    if (!is.null(oot$start)) {
+      dt_oot = dt[get(oot$order) >= oot$start]
+      dt = dt[get(oot$order) < oot$start]
+    } else if (!is.null(oot$ratio)) {
+      n_oot = dt[,floor(.N*oot$ratio)]
+
+      dt_oot = tail(dt, n_oot)
+      dt = head(dt, dt[,.N-n_oot])
+    }
+  }
+
   # name_dfs
   len_ratio = length(ratios)
   if (ratio_ > 0) len_ratio = length(ratios)-1
@@ -63,12 +85,10 @@ split_df = function(dt, y=NULL, ratios=c(0.7, 0.3), name_dfs=c('train', 'test'),
   if (length(name_dfs) > len_ratio) { name_dfs = name_dfs[seq_len(len_ratio)]
   } else if (length(name_dfs) < len_ratio) name_dfs = as.character(seq_len(len_ratio))
 
-
   # no_dfs
   no_dfs = kwargs[['no_dfs']]
   if (is.null(no_dfs) || no_dfs != length(name_dfs)) no_dfs = length(name_dfs)
 
-
   # set seed and partition
   set.seed(seed)
   if (is.null(y)) {
@@ -80,5 +100,14 @@ split_df = function(dt, y=NULL, ratios=c(0.7, 0.3), name_dfs=c('train', 'test'),
   # random sort
   lst_dfs = split(dt, by = 'ind', sorted = TRUE, keep.by = FALSE)[seq_len(no_dfs)]
   names(lst_dfs) = name_dfs
+
+  # oot
+  if (!is.null(dt_oot)) lst_dfs$oot = dt_oot
+
   return(lst_dfs)
 }
+
+
+df_split = function(dt, y=NULL, ratios=c(0.7, 0.3), name_dfs=c('train', 'test'), oot=list(order=NULL, start=NULL, ratio=NULL), seed=618, ...) {
+  UseMethod('split_df')
+}
